# galleon-maven-repo-patcher

* Patch a zipped maven repository with a maven repo patch (a subset of artifacts that have been patched).
* Generates galleon patches for each galleon feature-pack that needs to be patched.
* Remove old artifacts.
* Copy new artifacts from maven-repo patch
* Generate a new zipped repository containing all, ready to be consumed by Openshift image build.

Build

```mvn clean install```

Usage

```java -jar target/jboss-maven-repository-patcher-<version>.jar <original zipped repo>  <maven repo zipped patch> <generated zipped maven repo file> [added artifacts to FP mapping properties file]```

Output example:

```
java -jar ../target/jboss-maven-repository-patcher-1.0.0.Final-SNAPSHOT.jar ./jboss-eap-7.3.0.SP1-CR1-image-builder-maven-repository.zip  maven-repo-patch.zip output-repo.zip

Unzipping maven repo to tool-work-dir/maven-repo
Unzipping maven repo patch to tool-work-dir/repo-patch
Scanning feature-pack wildfly-core-galleon-pack-10.1.2.SP1-redhat-00001.zip
Scanning feature-pack wildfly-servlet-galleon-pack-7.3.0.SP1-redhat-00001.zip
Scanning feature-pack wildfly-galleon-pack-7.3.0.SP1-redhat-00001.zip
Zipping tool-work-dir/maven-repo/jboss-eap-7.3.0.SP1-image-builder-maven-repository to output-repo.zip


Created patches:
 * patch org.wildfly.core:wildfly-core-galleon-pack:10.1.2.SP1-patch-redhat-00001 for wildfly-core-galleon-pack-10.1.2.SP1-redhat-00001.zip
   - org.aesh:aesh:2.4.0.redhat-00001::jar => org.aesh:aesh:2.5.0.redhat-00001::jar
 * patch org.jboss.eap:wildfly-galleon-pack:7.3.0.SP1-patch-redhat-00001 for wildfly-galleon-pack-7.3.0.SP1-redhat-00001.zip
   - org.jboss.resteasy:resteasy-jaxrs:3.9.3.SP1-redhat-00001::jar => org.jboss.resteasy:resteasy-jaxrs:3.10-redhat-00001::jar

Added artifacts:
 - org/aesh/aesh/2.5.0.redhat-00001/*
 - org/jboss/resteasy/resteasy-jaxrs/3.10-redhat-00001/*

Deleted artifacts:
 - org/aesh/aesh/2.4.0.redhat-00001/*
 - org/jboss/resteasy/resteasy-jaxrs/3.9.3.SP1-redhat-00001/*

Content of patches.xml:
<patches>
<patch id="org.wildfly.core:wildfly-core-galleon-pack:10.1.2.SP1-patch-redhat-00001"/>
<patch id="org.jboss.eap:wildfly-galleon-pack:7.3.0.SP1-patch-redhat-00001"/>
</patches>
```

New artifacts properties file

In case the patched repository contains new artifacts (that are not present in the zipped maven repository), you need to provide a properties file that contains the information
needed to add the artifact to the right galleon feature-pack.
For example, if you have the new artifact : org.jboss.eap:wildfly-security-vault-tool that needs to be added to org.jboss.eap:wildfly-ee-galleon-pack,
then add the following line to the properties file:
```
org.jboss.eap:wildfly-ee-galleon-pack=org.jboss.eap:wildfly-security-vault-tool
```
The syntax of the properties file key is ```G:A``` of feature-pack.
The syntax of the properties file values is comma seperated list of ```G:A[:classifier]```

If you have multiple artifacts to install inside multiple fp, the file would look like:
```
org.jboss.eap:wildfly-ee-galleon-pack=org.jboss.eap:wildfly-security-vault-tool,org.foo.bar:myartifact::client
org.wildfly.core:wildfly-core-galleon-pack=org.foo.bar:myartifact2
```
The file is provided in the tool command line:
```
java -jar ../target/jboss-maven-repository-patcher-1.0.0.Final-SNAPSHOT.jar ./jboss-eap-7.3.0.SP1-CR1-image-builder-maven-repository.zip  maven-repo-patch.zip output-repo.zip added-artifacts.properties
```